@@ -7,6 +7,7 @@ from logic_bank.rule_bank.rule_bank import RuleBank
 from logic_bank.rule_bank import rule_bank_withdraw
 from logic_bank.exec_trans_logic.listeners import before_flush, before_commit
 from sqlalchemy.orm import session
+import logging
 
 
 def setup(a_session: session):
@@ -78,12 +79,15 @@ def compute_formula_execution_order() -> bool:
     Determine formula execution order based on "row.xx" references (dependencies),
     (or raise exception if cycles detected).
     """
-    list_rules = "\n\nValidate Rule Bank"
     rules_bank = RuleBank()
-
     for each_key in rules_bank.orm_objects:
         compute_formula_execution_order_for_class(class_name=each_key)
-    list_rules += rules_bank.__str__()
-    print(list_rules)
-    return True
 
+    logic_logger = logging.getLogger("logic_logger")
+    logic_logger.debug("\nThe following rules have been activated\n")
+    list_rules = rules_bank.__str__()
+    loaded_rules = list(list_rules.split("\n"))
+    for each_rule in loaded_rules:
+        logic_logger.debug(each_rule)
+    logic_logger.debug("")
+    return True
